==> centercontrol-service-2.0.2-20210927.021906-24-sources.jar: com/bizvane/centercontrolservice/models/vo/SysBrandConfigVo.java <==
package com.bizvane.centercontrolservice.models.vo;

/**
 * @author pc4
 */
public class SysBrandConfigVo {
    /**
     * 品牌成长值开关
     */
    private Boolean growthSwitch;

    /**
     * 成长值功能启用开关
     */
    private Boolean enableGrowthSwitch;

    /**
     * 品牌组织短信开关
     */
    private Boolean organizationSms;

    /**
     * 品牌组织短信功能启用开关
     */
    private Boolean enableOrganizationSms;


    /**
     * 微信解绑功能开关 0关 1开
     * @return
     */
    private Boolean wxUnbindSwitch;


    public Boolean getGrowthSwitch() {
        return growthSwitch;
    }

    public void setGrowthSwitch(Boolean growthSwitch) {
        this.growthSwitch = growthSwitch;
    }

    public Boolean getEnableGrowthSwitch() {
        return enableGrowthSwitch;
    }

    public void setEnableGrowthSwitch(Boolean enableGrowthSwitch) {
        this.enableGrowthSwitch = enableGrowthSwitch;
    }

    public Boolean getOrganizationSms() {
        return organizationSms;
    }

    public void setOrganizationSms(Boolean organizationSms) {
        this.organizationSms = organizationSms;
    }

    public Boolean getEnableOrganizationSms() {
        return enableOrganizationSms;
    }

    public void setEnableOrganizationSms(Boolean enableOrganizationSms) {
        this.enableOrganizationSms = enableOrganizationSms;
    }

    public Boolean getWxUnbindSwitch() {
        return wxUnbindSwitch;
    }

    public void setWxUnbindSwitch(Boolean wxUnbindSwitch) {
        this.wxUnbindSwitch = wxUnbindSwitch;
    }
}

==> centercontrol-service-2.0.2-20210927.031653-25-sources.jar: com/bizvane/centercontrolservice/models/vo/SysBrandConfigVo.java <==
package com.bizvane.centercontrolservice.models.vo;

/**
 * @author pc4
 */
public class SysBrandConfigVo {
    /**
     * 品牌成长值开关
     */
    private Boolean growthSwitch;

    /**
     * 成长值功能启用开关
     */
    private Boolean enableGrowthSwitch;

    /**
     * 品牌组织短信开关
     */
    private Boolean organizationSms;

    /**
     * 品牌组织短信功能启用开关
     */
    private Boolean enableOrganizationSms;


    /**
     * 微信解绑功能开关 0关 1开
     * @return
     */
    private Boolean wxUnbindSwitch;

    private Boolean wxElectMembershipCardSwitch;
    private Boolean alipayElectMembershipCardSwitch;


    public Boolean getGrowthSwitch() {
        return growthSwitch;
    }

    public void setGrowthSwitch(Boolean growthSwitch) {
        this.growthSwitch = growthSwitch;
    }

    public Boolean getEnableGrowthSwitch() {
        return enableGrowthSwitch;
    }

    public void setEnableGrowthSwitch(Boolean enableGrowthSwitch) {
        this.enableGrowthSwitch = enableGrowthSwitch;
    }

    public Boolean getOrganizationSms() {
        return organizationSms;
    }

    public void setOrganizationSms(Boolean organizationSms) {
        this.organizationSms = organizationSms;
    }

    public Boolean getEnableOrganizationSms() {
        return enableOrganizationSms;
    }

    public void setEnableOrganizationSms(Boolean enableOrganizationSms) {
        this.enableOrganizationSms = enableOrganizationSms;
    }

    public Boolean getWxUnbindSwitch() {
        return wxUnbindSwitch;
    }

    public void setWxUnbindSwitch(Boolean wxUnbindSwitch) {
        this.wxUnbindSwitch = wxUnbindSwitch;
    }

    public Boolean getWxElectMembershipCardSwitch() {
        return wxElectMembershipCardSwitch;
    }

    public void setWxElectMembershipCardSwitch(Boolean wxElectMembershipCardSwitch) {
        this.wxElectMembershipCardSwitch = wxElectMembershipCardSwitch;
    }

    public Boolean getAlipayElectMembershipCardSwitch() {
        return alipayElectMembershipCardSwitch;
    }

    public void setAlipayElectMembershipCardSwitch(Boolean alipayElectMembershipCardSwitch) {
        this.alipayElectMembershipCardSwitch = alipayElectMembershipCardSwitch;
    }
}
